@@ -26,7 +26,7 @@ from cubicweb import MultipleResultsError, NoResultError
 from cubicweb.toolsutils import underline_title
 from cubicweb.utils import admincnx
 
-from cubes.skos import ccplugin as skos
+from cubicweb_skos import ccplugin as skos
 from cubicweb_eac import ccplugin as eac
 
 from . import _massive_store_factory, _nohook_store_factory
@@ -43,15 +43,6 @@ eac.ImportEacData.options = (
 )
 
 
-skos.ImportSkosData.options = skos.ImportSkosData.options + (
-    ("naa-what", {
-        'type': 'string',
-        'help': ('"what" number of the Name Assigning Authority to import '
-                 'concept through (only relevant for LSCV import format)'),
-    }),
-)
-
-
 def _skos_drop_rql_store():
     """Remove "rql" store from ImportSkosData command.
 
@@ -75,6 +66,26 @@ _skos_drop_rql_store()
 del _skos_drop_rql_store
 
 
+def _skos_reword_scheme_option():
+    """Change "--scheme" option help of skos-import command to match SAEM
+    semantics (which relies on ARK instead of bare URI).
+    """
+    for name, value in skos.ImportSkosData.options:
+        if name == 'scheme':
+            value['help'] = (
+                'ARK identifier of an existing concept scheme to import concepts in '
+                '(only relevant for LCSV import format)'
+            )
+            break
+    else:
+        raise AssertionError(
+            'Could not find "scheme" option in ImportSkosData ccplugin command')
+
+
+_skos_reword_scheme_option()
+del _skos_reword_scheme_option
+
+
 def _enc(string):
     if PY2 and not isinstance(string, str):
         string = string.encode('utf-8')
@@ -127,7 +138,37 @@ _orig_run = skos.ImportSkosData.run
 
 @monkeypatch(skos.ImportSkosData)  # noqa: F811
 def run(self, args):
-    if self.get('format') == 'lcsv' and self.get('naa-what') is None:
-        print(u'command failed: --naa-what option is required for LCSV import format')
-        sys.exit(1)
+    if self.get('format') == 'lcsv':
+        scheme_ark = self.get('scheme')
+        if not scheme_ark:
+            print(u'command failed: --scheme option is required for LCSV import')
+            sys.exit(1)
+        scheme_ark = scheme_ark.strip().decode('utf-8')
+        appid = args[0]
+        connection = self.get_cnx(appid)
+        try:
+            with connection as cnx:
+                if scheme_ark.startswith(u'ark:/'):
+                    scheme_ark = scheme_ark[len(u'ark:/'):]
+                rset = cnx.find('ConceptScheme', ark=scheme_ark)
+                if not rset:
+                    print(u'command failed: no concept scheme found matching "%s"'
+                          % scheme_ark)
+                    raise Exception
+                scheme = rset.one()
+                # cubicweb-skos's command need a cwuri for --scheme.
+                setattr(self.config, 'scheme', scheme.cwuri)
+                # Per schema, ark_naa is optional for ConceptScheme.
+                if not scheme.ark_naa:
+                    print(u'command failed: specified concept scheme "%s" must have an ARK NAA set'
+                          % scheme_ark)
+                    raise Exception
+                naa_what = scheme.ark_naa[0].what
+                print(u'Importing concepts in %s' % scheme.absolute_url())
+        except Exception:
+            connection.repo.shutdown()
+            sys.exit(1)
+        # Set a "config" attribute which will be retrieved from metadata
+        # generator defined in __init__.py.
+        setattr(self.config, 'naa_what', naa_what)
     return _orig_run(self, args)
