@@ -46,8 +46,8 @@ class ArkOAIPMHRecordAdapter(OAIPMHRecordAdapter):
     """
 
     __abstract__ = True
-    __select__ = (OAIPMHRecordAdapter.__select__ &
-                  score_entity(lambda x: hasattr(x, 'ark')))
+    __select__ = (OAIPMHRecordAdapter.__select__
+                  & score_entity(lambda x: hasattr(x, 'ark')))
     identifier_attribute = 'ark'
 
     @property
