@@ -17,7 +17,10 @@
 """cubicweb-saem-ref postcreate script"""
 
 from cubicweb import _
-from cubicweb_saem_ref import workflows
+from cubicweb_saem_ref import (
+    create_default_naa,
+    workflows,
+)
 
 
 set_property('ui.site-title', u'Référentiel SAEM')
@@ -39,3 +42,10 @@ with cnx.deny_all_hooks_but():
     rql('SET X in_state S WHERE X is ConceptScheme, S eid %(s)s',
         {'s': schema_wf.state_by_name('published').eid})
 commit()
+
+if config.mode == 'test':
+    who, what = 'TEST', 0
+else:
+    who, what = config['default-ark-naa-who'], config['default-ark-naa-what']
+create_default_naa(cnx, who, what)
+commit()
