@@ -18,6 +18,7 @@
 
 import pytz
 
+from logilab.common.configuration import REQUIRED
 from logilab.common.date import ustrftime
 from logilab.common.decorators import monkeypatch
 
@@ -36,13 +37,36 @@ from cubicweb_skos.ccplugin import ImportSkosData
 import cubicweb_seda as seda
 import cubicweb_seda.dataimport as seda_dataimport
 
-from . import permanent_url, _massive_store_factory, _nohook_store_factory
+from . import (
+    create_default_naa,
+    permanent_url,
+    _massive_store_factory,
+    _nohook_store_factory,
+)
 
 # this import is needed to take account of pg_trgm monkeypatches
 # while executing cubicweb-ctl commands (db-rebuild-fti)
 from . import pg_trgm  # noqa pylint: disable=unused-import
 
 
+options = (
+    ('default-ark-naa-who',
+     {'type': 'string',
+      'default': REQUIRED,
+      'help': ('Name of default ARK Name Assigning Authority (who)'
+               ' (only used at database initialization)'),
+      'group': 'saem_ref',
+      'level': 0}),
+    ('default-ark-naa-what',
+     {'type': 'int',
+      'default': REQUIRED,
+      'help': ('Number of default ARK Name Assigning Authority (what)'
+               ' (only used at database initialization)'),
+      'group': 'saem_ref',
+      'level': 0}),
+)
+
+
 # override Entity.rest_path to use ark for entities which have one
 
 _orig_rest_path = Entity.rest_path
@@ -122,11 +146,12 @@ ImportSkosData.cw_store_factories['nohook'] = _nohook_store_factory
 @monkeypatch(seda_dataimport)
 def init_seda_scheme(cnx, title, _count=[]):
     description = u'edition 2009' if title.startswith('SEDA :') else None
+    who = cnx.vreg.config['default-ark-naa-who']
+    what = cnx.vreg.config['default-ark-naa-what']
     try:
-        ark_naa = cnx.find('ArkNameAssigningAuthority', what=25651).one()
+        ark_naa = cnx.find('ArkNameAssigningAuthority', who=who, what=what).one()
     except NoResultError:
-        ark_naa = cnx.create_entity(
-            'ArkNameAssigningAuthority', who=u'ADGIRONDE', what=25651)
+        ark_naa = create_default_naa(cnx, who, what)
     return cnx.create_entity('ConceptScheme', title=title, description=description,
                              ark_naa=ark_naa)
 
