@@ -186,9 +186,9 @@ class AddEntityComponent(component.CtxComponent):
     """Component with 'add' link to be displayed in 'same etype' views usually 'SameETypeListView'.
     """
     __regid__ = 'saem.add_entity'
-    __select__ = (component.CtxComponent.__select__ & multi_lines_rset() & has_permission('add') &
-                  is_instance('AuthorityRecord', 'ConceptScheme',
-                              'SEDAArchiveTransfer', 'SEDAArchiveUnit'))
+    __select__ = (component.CtxComponent.__select__ & multi_lines_rset() & has_permission('add')
+                  & is_instance('AuthorityRecord', 'ConceptScheme',
+                                'SEDAArchiveTransfer', 'SEDAArchiveUnit'))
     context = 'navtop'
     extra_kwargs = {'SEDAArchiveUnit': {'unit_type': 'unit_content'}}
 
