@@ -106,8 +106,8 @@ class EquivalentConceptOrTextField(ff.Field):
         if not entity.has_eid() or getattr(entity, self.name) != text_val:
             yield (ff.Field(name=self.name, role='subject', eidparam=True), text_val)
         if (not entity.has_eid() and equivalent_eids) \
-           or (entity.has_eid() and
-               set(x.eid for x in entity.equivalent_concept) != equivalent_eids):
+           or (entity.has_eid()
+               and set(x.eid for x in entity.equivalent_concept) != equivalent_eids):
             subfield = ff.Field(name='equivalent_concept', role='subject', eidparam=True)
             # register the association between the value and the field, because on entity creation,
             # process_posted will be recalled on the newly created field, and if we don't do that it
@@ -193,8 +193,8 @@ class CitationLinkView(EntityView):
                 xml_escape(entity.uri), xml_escape(desc),
                 xml_escape(title)))
         else:
-            title = (entity.note or
-                     u'{0} #{1}'.format(self._cw._('Citation'), entity.eid))
+            title = (entity.note
+                     or u'{0} #{1}'.format(self._cw._('Citation'), entity.eid))
             self.w(u'<i class="truncate">%s</i>' % title)
 
 
@@ -667,8 +667,8 @@ class AuthorityRecordAssociationRelationView(EntityView):
     """
     __regid__ = 'saem.authorityrecord.association_relations'
     __select__ = EntityView.__select__ & (
-        has_related_entities('association_from', role='object') |
-        has_related_entities('association_to', role='object'))
+        has_related_entities('association_from', role='object')
+        | has_related_entities('association_to', role='object'))
 
     def entity_call(self, entity, **kwargs):
         self.w(tags.h2(self._cw._('associated with')))
@@ -711,8 +711,8 @@ class ChronologicalRelationView(EntityView):
     """
     __regid__ = 'saem.authorityrecord.chronological_relation'
     __select__ = EntityView.__select__ & (
-        has_related_entities('chronological_successor', role='object') |
-        has_related_entities('chronological_predecessor', role='object'))
+        has_related_entities('chronological_successor', role='object')
+        | has_related_entities('chronological_predecessor', role='object'))
     title = _('ChronologicalRelation_plural')
 
     def entity_call(self, entity, **kwargs):
@@ -798,8 +798,8 @@ def _node(entity):
 
 class AuthorityRecordGraphView(EntityView):
     __select__ = EntityView.__select__ & (
-        has_related_entities('hierarchical_parent', role='object') |
-        has_related_entities('hierarchical_child', role='object'))
+        has_related_entities('hierarchical_parent', role='object')
+        | has_related_entities('hierarchical_child', role='object'))
 
     __regid__ = 'saem.authorityrecord.hierarchical-links'
     title = _('HierarchicalRelation_plural')
