@@ -110,11 +110,7 @@ def seda_transfer(cnx, **kwargs):
 
 
 def naa(cnx):
-    try:
-        return cnx.find('ArkNameAssigningAuthority').one()
-    except NoResultError:
-        with cnx.security_enabled(False, False):
-            return cnx.create_entity('ArkNameAssigningAuthority', who=u'TEST', what=0)
+    return cnx.find('ArkNameAssigningAuthority', what=0).one()
 
 
 def authority_with_naa(cnx, name=u'Default authority', **kwargs):
