@@ -125,8 +125,8 @@ class TreeTC(CubicWebTC):
             self.assertEqual([e.eid for e in bdo.container], [transfer.eid])
             self.assertEqual([e.eid for e in bdo_clone.container], [clone.eid])
 
-            self.failIf(cnx.execute('Any X GROUPBY X WHERE X container C HAVING COUNT(C) > 1'))
-            self.failIf(cnx.execute('Any X WHERE NOT X container C'))
+            self.assertFalse(cnx.execute('Any X GROUPBY X WHERE X container C HAVING COUNT(C) > 1'))
+            self.assertFalse(cnx.execute('Any X WHERE NOT X container C'))
 
 
 if __name__ == '__main__':
